@@ -42,7 +42,20 @@ module CTioga2
 Prints helps about short and long options available when run from the
 command-line.
 EOH
+
+        # Display help on the command-line
+    HelpOnCommand = 
+      Cmd.new("help-on", nil, 
+              "--help-on", [CmdArg.new('text') ]) do |plotmaker, cmd, options|
+      plotmaker.interpreter.doc.display_help_on(cmd, options)
+      exit 
+    end
     
+    HelpOnCommand.describe("Prints help text about the given command",
+                           <<EOH, GeneralGroup)
+Prints help about the given command
+EOH
+
     # Prints the version of ctioga2 used
     PrintVersion = Cmd.new("version", '-V', "--version", []) do |plotmaker|
       puts "This is ctioga2 version #{CTioga2::Version::version}"
@@ -126,6 +139,19 @@ EOH
     
     VerboseLogging.describe("Makes ctioga2 more verbose", <<EOH, GeneralGroup)
 With this on, ctioga2 outputs quite a fair amount of informative messages.
+EOH
+
+    Pause = 
+      Cmd.new("pause", nil,  "--pause",
+              [ CmdArg.new('boolean') ]) do |plotmaker, val|
+      plotmaker.pause_on_errors = val
+    end
+    
+    Pause.describe("Pause on errors", <<EOH, GeneralGroup)
+When this is on, the program will ask for confirmation before finishing, 
+when errors or warnings have been shown. This is especially useful on windows 
+or other environments where the terminal shuts down as soon as ctioga2 
+has finished.
 EOH
 
     # Write debugging information.
