@@ -80,6 +80,16 @@ EOD
 
     IntegerType = CmdType.new('integer', :integer, <<EOD)
 An integer.
+EOD
+
+    IntegerList = CmdType.new('integer-list', 
+                            {
+                              :type => :array,
+                              :subtype => :integer,
+                              :separator => /\s+|\s*,\s*/,
+                              :separator_out => " "
+                            }, <<EOD)
+A list of space-separated or comma-separated integers
 EOD
 
     PartialFloatRangeType = CmdType.new('partial-float-range', 
