@@ -16,6 +16,8 @@ require 'ctioga2/log'
 require 'ctioga2/data/datacolumn'
 require 'ctioga2/data/indexed-dtable'
 
+require 'set'
+
 module CTioga2
 
   # \todo now, port the backend infrastructure...
@@ -57,6 +59,9 @@ module CTioga2
 
         # Cache for the indexed dtable
         @indexed_dtable = nil
+
+        # Cache for the homogeneous dtables
+        @homogeneous_dtables = nil
       end
 
       # Creates a 
@@ -264,18 +269,19 @@ module CTioga2
       # Average all the non-X values of successive data points that
       # have the same X values. It is a naive version that also
       # averages the error columns.
-      def average_duplicates!
+      def average_duplicates!(mode = :avg)
         last_x = nil
         last_x_first_idx = 0
         xv = @x.values
         i = 0
         vectors = all_vectors
+        nb_x = 0
         while i < xv.size
           x = xv[i]
           if ((last_x == x) && (i != (xv.size - 1)))
             # Do nothing
           else
-            if last_x_first_idx < (i - 1)  || 
+            if last_x_first_idx <= (i - 1)  || 
                 ((last_x == x) && (i == (xv.size - 1)))
               if i == (xv.size - 1)
                 e = i
@@ -283,24 +289,21 @@ module CTioga2
                 e = i-1
               end                 # The end of the slice.
 
-              ## \todo In real, to do this properly, one would
-              # have to write a proper function in DataColumn that
-              # does averaging over certain indices possibly more
-              # cleverly than the current way to do.
-              for v in vectors
-                subv = v[last_x_first_idx..e]
-                ave = subv.sum/subv.size
-                v.slice!(last_x_first_idx+1, e - last_x_first_idx)
-                v[last_x_first_idx] = ave
+              # Now, we delegate to the columns the task of averaging.
+              @x.average_over(last_x_first_idx, e, nb_x, :avg)
+              for c in @ys
+                c.average_over(last_x_first_idx, e, nb_x, mode)
               end
-              i -= e - last_x_first_idx
+              nb_x += 1
             end
             last_x = x
             last_x_first_idx = i
           end
           i += 1
         end
-        
+        for c in all_columns
+          c.resize!(nb_x)
+        end
       end
 
       # Applies formulas to values. Formulas are like text-backend
@@ -340,19 +343,111 @@ module CTioga2
         return Dataset.new(name + "_mod", result)
       end
 
+      # Takes a list of x and y values, and subdivise into
+      # non-overlapping groups.
+      def self.subdivise(x,y, x_idx, y_idx)
 
-      # Returns an IndexedDTable representing the XYZ
-      # data. Information about errors are not included.
-      #
-      # @todo For performance, this will have to be turned into a real
-      # Dtable or Dvector class function. This function is just going
-      # to be *bad* ;-)
-      #
-      # @todo The cache should be invalidated when the contents of the
-      # Dataset changes (but that will be *real* hard !)
-      def indexed_table
-        if @indexed_dtable
-          return @indexed_dtable
+        # We make a list of sets. Each element of the list represent
+        # one column, and in each set we store the index of of lines
+        # that contain data.
+
+        cols = []
+        
+        x.each_index do |i|
+          ix = x_idx[x[i]]
+          iy = y_idx[y[i]]
+
+          cols[ix] ||= Set.new
+          cols[ix].add(iy)
+        end
+
+        # The return value is an array of [ [xindices] [yindices]]
+        ret = []
+
+        # Now, the hard part.
+
+        # We run for as long as there are sets ?
+        fc = 0
+        while fc < cols.size
+          # We start with the set of the current column
+          st = cols[fc]
+          # Empty, go to next column
+          if st.size == 0
+            fc += 1
+            next
+          end
+
+          # Set columns that contain the set
+          set_cols = [fc]
+          # Now, we look for restrictions on the set.
+          fc2 = fc + 1
+          while fc2 < cols.size
+            # if non-void intersection, we stick to that
+            inter = st.intersection(cols[fc2])
+            # p [fc, fc2, st, inter]
+            if inter.size > 0
+              st = inter
+              set_cols << fc2
+              fc2 += 1
+              break
+            end
+
+            fc2 += 1
+            # Try to implement other kinds of restrictions?
+          end
+
+          # Now, we have a decent set, we go on until the intersection
+          # with the set is not the set.
+          while fc2 < cols.size
+            inter = st.intersection(cols[fc2])
+            if inter.size > 0
+              if inter.size == st.size
+                set_cols << fc2
+              else
+                break
+              end
+            end
+            fc2 += 1
+          end
+
+          # Now, we have a set and all the indices that match.
+          ret << [ set_cols.dup.sort, st.to_a.sort ]
+          # And, now, go again through all the columns and remove the set
+          for c in set_cols
+            cols[c].subtract(st)
+          end
+        end
+
+        return ret
+      end
+
+      # Takes a list of indices, the corresponding vector (ie mapping
+      # the indices to the vector gives the actual coordinates) and
+      # returns a list of arrays of indices with homogeneous deltas.
+      def self.homogenenous_deltas_indices(indices, vector, tolerance = 1e-3)
+        vct = indices.map do |i|
+          vector[i]
+        end
+        subdiv = Utils::split_homogeneous_deltas(vct, tolerance)
+        rv = []
+        idx = 0
+        for s in subdiv
+          rv << indices[idx..idx+s.size-1]
+          idx += s.size
+        end
+        if idx != indices.size
+          error { "blundered ?" }
+        end
+        return rv
+      end
+
+      # Returns a series of IndexedDTable representing the XYZ data.
+      def homogeneous_dtables()
+        if @homogeneous_dtables
+          return @homogeneous_dtables
+        end
+        if @ys.size < 2
+          raise "Need at least 3 data columns in dataset '#{@name}'"
         end
         # We convert the index into three x,y and z arrays
         x = @x.values.dup
@@ -377,6 +472,119 @@ module CTioga2
           i += 1
         end
 
+        fgrps = []
+        if x.size != xvals.size * yvals.size
+          # This is definitely not a homogeneous map
+          fgrps = Dataset.subdivise(x, y, x_index, y_index)
+        else
+          fgrps = [ [ x_index.values, y_index.values ] ]
+        end
+
+        # Now, we resplit according to the deltas:
+        grps = []
+        for grp in fgrps
+          xv, yv = *grp
+
+          xv_list = Dataset.homogenenous_deltas_indices(xv, xvals)
+          yv_list = Dataset.homogenenous_deltas_indices(yv, yvals)
+
+          for cxv in xv_list
+            for cyv in yv_list
+              grps << [ cxv, cyv]
+            end
+          end
+        end
+
+        # Now we construct a list of indexed dtables
+        rv = []
+        for grp in grps
+          xv = grp[0].sort
+          yv = grp[1].sort
+
+          # Build up intermediate hashes
+          xvh = {}
+          xvl = []
+          idx = 0
+          for xi in xv
+            val = xvals[xi]
+            xvh[val] = idx
+            xvl << val
+            idx += 1
+          end
+
+          yvh = {}
+          yvl = []
+          idx = 0
+          for yi in yv
+            val = yvals[yi]
+            yvh[val] = idx
+            yvl << val
+            idx += 1
+          end
+          
+          table = Dobjects::Dtable.new(xv.size, yv.size)
+          # We initialize all the values to NaN
+          table.set(0.0/0.0)
+        
+          x.each_index do |i|
+            ix = xvh[x[i]]
+            next unless ix
+            iy = yvh[y[i]]
+            next unless iy
+            # Y first !
+            table[iy, ix] = z[i]
+          end
+          rv << IndexedDTable.new(xvl, yvl, table)
+        end
+        @homogeneous_dtables = rv
+        return rv
+      end
+        
+
+
+      # Returns an IndexedDTable representing the XYZ
+      # data. Information about errors are not included.
+      #
+      # @todo For performance, this will have to be turned into a real
+      # Dtable or Dvector class function. This function is just going
+      # to be *bad* ;-)
+      #
+      # @todo The cache should be invalidated when the contents of the
+      # Dataset changes (but that will be *real* hard !)
+      def indexed_table
+        if @indexed_dtable
+          return @indexed_dtable
+        end
+        if @ys.size < 2
+          raise "Need at least 3 data columns in dataset '#{@name}'"
+        end
+        # We convert the index into three x,y and z arrays
+        x = @x.values.dup
+        y = @ys[0].values.dup
+        z = @ys[1].values.dup
+        
+        xvals = x.sort.uniq
+        yvals = y.sort.uniq
+        
+        # Now building reverse hashes to speed up the conversion:
+        x_index = {}
+        i = 0
+        xvals.each do |v|
+          x_index[v] = i
+          i += 1
+        end
+
+        y_index = {}
+        i = 0
+        yvals.each do |v|
+          y_index[v] = i
+          i += 1
+        end
+
+        if x.size != xvals.size * yvals.size
+          error {"Heterogeneous, stopping here for now"}
+        end
+
         table = Dobjects::Dtable.new(xvals.size, yvals.size)
         # We initialize all the values to NaN
         table.set(0.0/0.0)
