@@ -78,8 +78,8 @@ module CTioga2
         end
         
         csv.describe("reads CSV files", 
-                            <<"EOH", "backend-text")
-Now parse the following data files as CSV.
+                     <<"EOH", "backend-text")
+Now parse the following data files as CSV. Equivalent to
 
 # text /separator=/[,;]/
 EOH
@@ -96,7 +96,7 @@ EOH
           begin
             datasets << backend.dataset(s)
           rescue Exception => e
-            error { "Could not load dataset #{s} -- #{e}" }
+            error { "Could not load dataset '#{s}' with backend '#{backend.description.name }':\n\t -> #{e}" }
             debug { "#{e.backtrace.join("\n")}" }
           end
         end
@@ -373,6 +373,7 @@ EOH
               }) do |plotmaker,opts|
       ds = plotmaker.data_stack.specified_dataset(opts)
       if opts['save']
+        # Writing
         out = open(opts['save'], 'w')
       else
         out = STDOUT
