@@ -24,13 +24,6 @@ module CTioga2
       # * inclusion of curves
       # * legends
       # * a way to set/get its figure boundaries.
-      #
-      # @todo It would be interesting to feature several layers:
-      # background/normal/foreground, that could be addressed just
-      # using options to drawing commands
-      #
-      # @todo It would also be interesting to offer the possibility to
-      # output non-clipped objects.
       class Subplot < Container
 
         # Various stylistic aspects of the plot, as a
@@ -138,6 +131,12 @@ module CTioga2
             bounds[k] ||= Types::SimpleRange.new(nil,nil)
             bounds[k].override(b)
           end
+          for k, b in bounds
+            if ! b.valid?
+              error { "Invalid computed range, you probably have only empty datasets" }
+              bounds[k] = Types::SimpleRange.new(0.0,1.0)
+            end
+          end
           return bounds
         end
 
@@ -183,15 +182,16 @@ module CTioga2
               dx = t.convert_figure_to_output_dx(1.0)
               dy = t.convert_figure_to_output_dy(1.0)
               
-              frm = [0.0, dx/@style.frame_real_size, 
-                     -dy/@style.frame_real_size, 0.0]
+              frm = [0.0, dx/(@style.frame_real_size * t.scaling_factor), 
+                     -dy/(@style.frame_real_size * t.scaling_factor), 0.0]
               @computed_boundaries = {
                 :bottom => Types::SimpleRange.new(frm[0], frm[1]),
                 :left => Types::SimpleRange.new(frm[2], frm[3]),
               }                
               t.set_bounds(frm)
             else
-              t.set_bounds(real_boundaries.to_a)
+              bnds = real_boundaries.to_a
+              t.set_bounds(bnds)
             end
 
             # First, gather up all elements by depth
