@@ -59,39 +59,6 @@ module CTioga2
 
       end
 
-      # This class represents all the stylistic information necessary
-      # to draw a line parallel to a certain direction, indicated by
-      # an angle (default to horizontal)
-      class OrientedLineStyle < StrokeStyle
-        # The angle, in degrees.
-        typed_attribute :angle, 'float'
-
-        # The alignment of the line with respect to the point given.
-        typed_attribute :origin, 'justification'
-
-        # len is a dimension
-        def draw_oriented_line(t, xo, yo, len)
-
-          angle = @angle || 0.0
-
-          dx,dy = *len.to_figure(t, angle)
-
-          case @origin || Tioga::FigureConstants::LEFT_JUSTIFIED
-          when Tioga::FigureConstants::LEFT_JUSTIFIED
-            x1, y1 = xo, yo
-            x2, y2 = xo + dx, yo + dy
-          when Tioga::FigureConstants::CENTERED
-            x1, y1 = xo - 0.5 * dx, yo - 0.5 * dy
-            x2, y2 = xo + 0.5 * dx, yo + 0.5 * dy
-          when Tioga::FigureConstants::RIGHT_JUSTIFIED
-            x1, y1 = xo - dx, yo - dy
-            x2, y2 = xo, yo
-          end
-
-          draw_line(t, x1, y1, x2, y2)
-        end
-        
-      end
 
       # This class represents all the stylistic information to draw a
       # Marker.
@@ -102,42 +69,81 @@ module CTioga2
       #   be handled directly in the marker specification...
       class MarkerStyle < BasicStyle
 
-        # The color
-        typed_attribute :color, 'color'
-        
         # The marker
         typed_attribute :marker, 'marker'
 
         # The marker scale
         typed_attribute :scale, 'float'
 
+        # The angle
+        typed_attribute :angle, 'float'
+
+        # The default for color
+        typed_attribute :color, 'color-or-false'
+
+        # The stroke color
+        typed_attribute :line_color, 'color-or-false'
+
+        # The fill color
+        typed_attribute :fill_color, 'color-or-false'
+
+        # The stroke width
+        typed_attribute :line_width, 'float'
+
         # Shows the marker at a given location/set of locations.
         # 
         # \p override is a hash that can override part of the
         # dictionnary specification.
         def draw_markers_at(t, x, y, override = nil)
           return if (! @marker || @marker == 'None')
+
+          dict = { 
+            'marker' => @marker
+          }
+          if @line_width
+            dict['stroke_width'] = @line_width
+          end
+          if !(@fill_color.nil?) || !(@line_color.nil?)
+            dict['fill_color'] = @fill_color.nil? ? @color : @fill_color
+            dict['stroke_color'] = @line_color.nil? ? @color : @line_color
+            dict['rendering_mode'] = 
+              if dict['fill_color']
+                if dict['stroke_color']
+                  Tioga::FigureConstants::FILL_AND_STROKE
+                else
+                  Tioga::FigureConstants::FILL
+                end
+              else
+                Tioga::FigureConstants::STROKE
+              end
+            dict.strip_if_false!(%w{fill_color stroke_color})
+          else
+            dict['color'] = @color
+            if ! @color
+              return            # Nothing to do !
+            end
+          end
+          if @angle
+            dict['angle'] = @angle
+          end
+          
+          if x.is_a? Numeric
+            dict['x'] = x
+            dict['y'] = y
+          else
+            dict['Xs'] = x
+            dict['Ys'] = y
+          end
+
+          if @scale
+            dict['scale'] = @scale
+          end
+          if override
+            dict.merge!(override)
+          end
           t.context do
             ## \todo allow custom line types for markers ?
             t.line_type = LineStyles::Solid
-            dict = { 
-              'marker' => @marker, 
-              'color' => @color
-            }
-            if x.is_a? Numeric
-              dict['x'] = x
-              dict['y'] = y
-            else
-              dict['Xs'] = x
-              dict['Ys'] = y
-            end
-
-            if @scale
-              dict['scale'] = @scale
-            end
-            if override
-              dict.merge!(override)
-            end
             t.show_marker(dict)
           end
         end
