@@ -40,6 +40,9 @@ module CTioga2
           # parameter. It is a hash. 
           attr_accessor :sets
 
+          # The name of the default set, when it isn't 'default'
+          attr_accessor :default_set
+
           # The description of the parameter.
           attr_accessor :description
           
@@ -60,8 +63,16 @@ module CTioga2
           def initialize(name, type, sets, description, 
                          short_option = nil, disable_cmds = false)
             @name = name
-            @type = type 
-            @sets = sets
+            @type = type
+            if sets
+              # If the sets is an array, it is of the form [sets, 'default set']
+              if sets.is_a? Array
+                @sets = sets[0]
+                @default_set = sets[1]
+              else
+                @sets = sets
+              end
+            end
             @description = description
             @short_option = short_option
             @disable_commands = disable_cmds
@@ -81,7 +92,9 @@ module CTioga2
           # Returns a suitable default set for the given object.
           def default_set
             return nil unless @sets
-            if @sets.key? 'default'
+            if @default_set
+              return @sets[@default_set]
+            elsif @sets.key? 'default'
               return @sets['default']
             else
               @sets.each do |k,v|
@@ -249,22 +262,36 @@ module CTioga2
           }
           @parameters_carrays = {}
           for target, param in self.class.parameters
+            # There should be a way to do that !
             set = param.default_set
             if set
               @parameters_carrays[target] = CircularArray.new(set)
             end
           end
+
+          @next_style = nil
+        end
+
+        # Sets the style to be returned from the next call to #next
+        # (not counting the effect of the options passed)
+        def set_next_style(stl)
+          @next_style = stl
         end
 
         # Gets the style for the next curve. The _one_time_ hash
         # contains values 'parameter name' (name, and not target) =>
         # value that are used for this time only.
         def next(one_time = {})
-          base = {}
-          for target, array in @parameters_carrays
-            base[target] = array.next
+          if @next_style
+            base = @next_style
+            @next_style = nil
+          else
+            base = {}
+            for target, array in @parameters_carrays
+              base[target] = array.next
+            end
+            base.merge!(@override_parameters)
           end
-          base.merge!(@override_parameters)
           base.merge!(hash_name_to_target(one_time))
           return CurveStyle.from_hash(resolve_links(base))
         end
@@ -327,18 +354,29 @@ module CTioga2
         simple_parameter 'line_style', 'line style', Sets::LineStyleSets
 
         # Markers
-        simple_parameter  'marker', 'marker', Sets::MarkerSets, '-m'
+        simple_parameter 'marker', 'marker', Sets::MarkerSets, '-m'
 
         simple_parameter 'marker_color', "marker color", Sets::ColorSets
 
+        simple_parameter 'marker_fill_color', "marker fill color", [Sets::ColorSets, 'nil']
+
+        simple_parameter 'marker_line_color', "marker stroke color", [Sets::ColorSets, 'nil']
+
         simple_parameter 'marker_scale', "marker scale", Sets::LineWidthSets
 
+        simple_parameter 'marker_angle', "marker angle", nil
+
+        simple_parameter 'marker_line_width', "marker line width", nil 
+
         simple_parameter 'marker_min_scale', "marker scale", nil
 
         # Error bars:
         simple_parameter 'error_bar_color', "error bar color", 
         Sets::ColorSets
 
+        simple_parameter 'error_bar_line_width', "error bar line width", 
+        Sets::LineWidthSets
+
         # Location:
         define_parameter 'location_xaxis', 'xaxis', 
         nil, "X axis", nil, true
@@ -470,7 +508,40 @@ module CTioga2
           return tv
         end
       end
-    end
+
+      SkipCommand = 
+        Cmd.new("skip",nil,"--skip", 
+                [], {'number' => CmdArg.new("integer")}
+               ) do |plotmaker, opts|
+        number = opts['number'] || 1
+        fct = plotmaker.curve_generator.style_factory
+        while number > 0
+          number -= 1
+          fct.next
+        end
+      end
+
+      SkipCommand.describe('Skips next curve style', 
+                           <<EOH, CurveStyleFactory::CurveStyleGroup)
+This command acts as if one (or @number@) dataset had been drawn with 
+respect to the style of the next dataset to be drawn.
+EOH
+
+      ReuseCommand = 
+        Cmd.new("reuse-style",nil,"--reuse-style", 
+                [CmdArg.new('object')], {}
+               ) do |plotmaker, obj, opts|
+        stl = obj.curve_style.to_hash
+        plotmaker.curve_generator.style_factory.set_next_style(stl)
+      end
+
+      ReuseCommand.describe('Reuse the style of a previous curve', 
+                            <<EOH, CurveStyleFactory::CurveStyleGroup)
+After using this command, the next curve will have the same style as the 
+curve whose name was given as the first argument (it is the name given to 
+the `/id=` option to plot.
+EOH
+end
 
     # Now, we document some aspects of the above created commands
     c = Commands::Command
