@@ -51,10 +51,58 @@ module CTioga2
         # _value_ oriented along the given _orientation_
         def initialize(type, value, orientation = :x)
           @type = type
+          if not @type.is_a? Symbol
+            raise "Invalid value for the dimension type: '#{@type}'"
+          end
           @value = value
           @orientation = orientation
         end
 
+        def self.make_dimension(val, orient = :x, default = :figure)
+          if val.is_a? Dimension
+            return val
+          else
+            return Dimension.new(default, val, orient)
+          end
+        end
+
+        # Gets the angle along the given direction
+        def self.get_angle(t, dx, dy)
+          dx = make_dimension(dx, :x).to_bp(t)
+          dy = make_dimension(dy, :y).to_bp(t)
+          return 180 * Math::atan2(dy, dx)/Math::PI
+        end
+
+        def -@
+          return Dimension.new(@type, -@value, @orientation)
+        end
+
+        # Returns a dimension corresponding to the distance.
+        def self.get_distance(t, dx, dy)
+          dx = make_dimension(dx, :x).to_bp(t)
+          dy = make_dimension(dy, :y).to_bp(t)
+          return Dimension.new(:bp, (dx**2 + dy**2)**0.5)
+        end
+
+        # Adjusts the given line by adding the dimensions on the left
+        # and on the right (can be negative).
+        #
+        # Returns the new [x1, y1, x2, y2]
+        def self.adjust_line(t, x1, y1, x2, y2, left, right)
+          dx = x2 - x1
+          dy = y2 - y1
+          dst = get_distance(t, x2-x1, y2-y1).to_bp(t)
+          lf = left.to_bp(t)/dst
+          rf = right.to_bp(t)/dst
+
+          x1 -= lf * dx
+          y1 -= lf * dy
+          x2 += rf * dx
+          y2 += rf * dy
+          return [x1, y1, x2, y2]
+        end
+          
+
         # Converts the Dimension to the *figure* coordinates of the
         # *current* figure in _t_.
         #
@@ -86,7 +134,7 @@ module CTioga2
           
           case @type
           when :bp
-            return t.send("convert_output_to_figure_d#{orientation}", @value) * 10
+            return t.send("convert_output_to_figure_d#{orientation}", @value) * t.scaling_factor
           when :dy
             return t.send("default_text_height_d#{orientation}") * @value
           when :frame
@@ -110,7 +158,7 @@ module CTioga2
         def to_bp(t, orientation = nil)
           orientation ||= @orientation
           return t.send("convert_figure_to_output_d#{orientation}", 
-                        to_figure(t, orientation)) / 10.0
+                        to_figure(t, orientation)) / t.scaling_factor
         end
 
         # Converts the Dimension to the *frame* coordinates of the
