@@ -221,6 +221,17 @@ module CTioga2
 
     # The stack of CurveStyle objects that were used so far.
     attr_accessor :curve_style_stack
+
+    # Whether or not one should pause at the end if there are
+    # errors. Useful on windows, where the windows closes before one
+    # has a chance to see anything.
+    attr_accessor :pause_on_errors
+
+    # If not empty, a Makefile file where the dependencies are written out
+    attr_accessor :makefile_dependencies
+
+    # The resolution of the PDF file
+    attr_accessor :pdf_resolution
     
 
     # The first instance of PlotMaker created
@@ -291,6 +302,15 @@ module CTioga2
         debug { format_exception(e) }
         fatal { "#{e.message}" }
       end
+      errs = Log.counts[:error]
+      warns = Log.counts[:warn]
+      if errs + warns > 0
+        puts "ctioga2 finished with #{errs} errors and #{warns} warning"
+        if @pause_on_errors
+          puts "Hit ENTER to exit"
+          STDIN.gets
+        end
+      end
     end
 
     # Flushes the current root object and starts a new one:
@@ -354,7 +374,7 @@ module CTioga2
       end
 
       # We always cd into the target directory for creading the
-      Dir.chdir(path.dirname) do
+      Utils::chdir(path.dirname) do
         fn = path.basename.to_s
 
         efn = fn.gsub(/[.\s]/) do |x|
@@ -391,6 +411,14 @@ module CTioga2
 
       file = path.to_s + ".pdf"
 
+      if @makefile_dependencies
+        File.open(@makefile_dependencies, "w") do |f|
+          deps = Utils::used_files.values
+          # TODO: handle spaces
+          f.puts "#{file}: #{deps.join(" ")}"
+        end
+      end
+
       # Feed it
       @postprocess.process_file(file, last)
       return file
@@ -437,7 +465,7 @@ module CTioga2
 
     # Creates a new FigureMaker object and returns it
     def create_figure_maker
-      t = Tioga::FigureMaker.new
+      t = Tioga::FigureMaker.new(@pdf_resolution || 100)
       t.tex_preamble += @latex_preamble
       t.autocleanup = @cleanup
 
@@ -610,6 +638,25 @@ EOD
                              <<EOH, OutputSetupGroup)
 Sets the size of the output PDF file, in real units. Takes arguments in the 
 form of 12cm x 3in (spaces can be omitted).
+EOH
+
+    ResolutionCommand = 
+      Cmd.new("resolution", false,"--resolution", 
+              [ CmdArg.new('float') ],
+              ) do |plotmaker, size, options|
+      plotmaker.pdf_resolution = size
+    end
+
+    ResolutionCommand.describe('Sets the output resolution', 
+                               <<EOH, OutputSetupGroup)
+By default, ctioga2 has a resolution of 1/100th of a postscript
+point. This is clearly enough for most tasks, but you can increase it
+should you need, or decrease it to generate possibly a little more
+jaggy but less large PDF files.
+
+The number given is the number of output points per postscript point.
+
+Better change that at the beginning of the plot.
 EOH
 
     CleanupCommand = 
@@ -802,6 +849,17 @@ want any information to leak.
 Please note that this will not log the values of the CTIOGA2_PRE and
 CTIOGA2_POST variables, so you might still get a different output if
 you make heavy use of those.
+EOH
+
+    DepsCommand = 
+      Cmd.new("dependencies",nil,"--dependencies", 
+              [CmdArg.new('file') ]) do |plotmaker,val|
+      plotmaker.makefile_dependencies = val
+    end
+    
+    DepsCommand.describe('Save dependencies', 
+                         <<EOH, OutputSetupGroup)
+Saves the dependencies as a Makefike into the given file name.
 EOH
 
   end
