@@ -59,6 +59,11 @@ module CTioga2
       end
     end
 
+    # Returns true if the argument is a finite number
+    def self.finite_number?(flt)
+      return (flt.is_a?(Numeric) and flt.to_f.finite?)
+    end
+
     # Converts a number to a float while trying to stay as lenient as
     # possible
     def self.txt_to_float(txt)
@@ -144,7 +149,7 @@ module CTioga2
       return formula
     end
 
-
+    # Sorts strings according to their numeric suffix
     def self.suffix_numeric_sort(strings)
       strings.sort do |a,b|
         a =~ /.*?(\d+)$/
@@ -160,6 +165,24 @@ module CTioga2
       end
     end
 
+    # Returns the nth first modes
+    def self.average_vector(vect, istart, iend, n = 1)
+      rv = [0] * n
+      nb = 0
+      istart.upto(iend) do |i|
+        v = 1
+        y = vect[i]
+        n.times do |j|
+          v *= y
+          rv[j] += v
+        end
+        nb += 1
+      end
+
+      return rv.map do |v|
+        v/nb
+      end
+    end
 
     # Groups the given strings by prefixes
 
@@ -176,6 +199,76 @@ module CTioga2
       return sets_by_prefix
     end
 
+    # An instrumentized version of Dir::chdir 
+    def self.chdir(dir, &blk)
+      @current_dirs ||= []
+      @current_dirs << Pathname.new(dir)
+      Dir::chdir(dir, &blk)
+      @current_dirs.pop
+    end
+
+    # A constant holding a relation extension -> command to decompress
+    # (to be fed to sprintf with the filename as argument)
+    UNCOMPRESSORS = {
+      ".gz" => "gunzip -c %s",
+      ".bz2" => "bunzip2 -c %s",
+      ".lzma" => "unlzma -c %s",
+      ".lz" => "unlzma -c %s",
+      ".xz" => "unxz -c %s",
+    }
+
+    # This opens a file for reading, keeping track of the opened files
+    # and possibly transparently decompressing files when
+    # applicable. Returns the file object, or runs the given block
+    # with it, closing the file at the end.
+    def self.open(file)
+      if not File.readable?(file)
+        # Try to find a compressed version
+        for ext,method in UNCOMPRESSORS
+          if File.readable? "#{file}#{ext}"
+            info { "Using compressed file #{file}#{ext} in stead of #{file}" }
+            ff = "#{file}#{ext}"
+            handle = IO.popen(method % ff)
+            break
+          end
+        end
+      else
+        for ext, method in UNCOMPRESSORS
+          if file =~ /#{ext}$/
+            info { "Taking file #{file} as a compressed file" }
+            ff = file
+            handle = IO.popen(method % file)
+            break
+          end
+        end
+      end
+      if ! handle
+        ff = file
+        handle = File::open(file)
+      end
+
+      # Unwrap directory 
+      @used_files ||= {}
+
+      @current_dirs ||= []
+      rf = (@current_dirs + [file]).inject :+
+      rff = (@current_dirs + [ff]).inject :+
+      # The files referenced
+      @used_files[rf] = rff
+      if block_given?
+        yield handle
+        handle.close
+      else
+        return handle
+      end
+    end
+
+
+    # Returns the list of files that were read by ctioga2
+    def self.used_files()
+      return @used_files || {}
+    end
+
 
 
     NaturalSubdivisions = [1.0, 2.0, 5.0, 10.0]
@@ -232,6 +325,13 @@ module CTioga2
       return Math.log10(a.first).send(method)
     end
 
+    # Returns the segment scaled about its center by the given factor
+    def self.scale_segment(left, right, factor)
+      dx = 0.5*(right - left)
+      mid = 0.5*(right + left)
+      return mid - factor * dx, mid + factor * dx
+    end
+
 
     # Transcodes the given string from all encodings into the target
     # encoding until an encoding is found in which the named file
@@ -278,6 +378,39 @@ module CTioga2
       return ret
     end
 
+    # Takes a vector, and splits it into a series of contiguous
+    # subvectors which 
+    def self.split_homogeneous_deltas(vect, tolerance = 1e-4)
+      rv = []
+      idx = 1
+      dx = nil
+      lst = nil
+      while idx < vect.size
+        cdx = vect[idx] - vect[idx - 1]
+        if ! dx 
+          dx = cdx
+          lst = Dobjects::Dvector.new()
+          rv << lst
+          lst << vect[idx-1] << vect[idx]
+        else
+          if (cdx - dx).abs <= tolerance * dx
+            # keep going
+            lst << vect[idx]
+          else
+            dx = nil
+          end
+        end
+        idx += 1
+      end
+
+      # Flush the last one if alone
+      if ! dx
+        nv = Dobjects::Dvector.new()
+        nv << vect.last
+        rv << nv
+      end
+      return rv
+    end
 
 
     # Cross-platform way of finding an executable in the $PATH.
@@ -348,8 +481,7 @@ module CTioga2
       end
 
       return ret
-     end
-
+    end
 
     # Returns a hash value -> [elements] in which the elements are in
     # the same order
@@ -431,8 +563,7 @@ module CTioga2
     # Watched text names
     attr_accessor :watched_names
 
-    # A left, bottom, right, up bounding box (in output coordinates
-    # divided by 10)
+    # A left, bottom, right, up bounding box (postscript points)
     attr_accessor :bb
 
     def initialize
@@ -458,11 +589,11 @@ module CTioga2
         return margins
       end
       left, top, right, bottom = *margins.to_frame_coordinates(t)
-      
-      xl = 0.1 * t.convert_page_to_output_x(t.convert_frame_to_page_x(left))
-      xr = 0.1 * t.convert_page_to_output_x(t.convert_frame_to_page_x(right))
-      yt = 0.1 * t.convert_page_to_output_y(t.convert_frame_to_page_y(top))
-      yb = 0.1 * t.convert_page_to_output_y(t.convert_frame_to_page_y(bottom))
+      scl = 1/t.scaling_factor
+      xl = scl * t.convert_page_to_output_x(t.convert_frame_to_page_x(left))
+      xr = scl * t.convert_page_to_output_x(t.convert_frame_to_page_x(right))
+      yt = scl * t.convert_page_to_output_y(t.convert_frame_to_page_y(top))
+      yb = scl * t.convert_page_to_output_y(t.convert_frame_to_page_y(bottom))
 
       vals = [ xl - @bb[0], @bb[2] - xr, @bb[3] - yt, yb - @bb[1]].map do |x|
         x += padding
@@ -554,9 +685,19 @@ class Hash
     self.delete(old)
   end
 
+  # Strip the given keys if they evaluate to false
+  def strip_if_false!(keys)
+    for k in keys
+      if key?(k) and (not self[k])
+        self.delete(k)
+      end
+    end
+  end
+
 end
 
 
+
 class String
   # Splits a string into substrings at the given regexp, but only if
   # the splitting occurs at top-level with respect to parentheses.
