@@ -6,6 +6,14 @@
 
 . ./test-include.sh
 
-$ct -x '$x$ values in % of stuff' 'sin(x)' -y '$y$ values' 
+# $ct -x '$x$ values in % of stuff' 'sin(x)' -y '$y$ values' 
+
+# $ct -x '$x$ values in % of stuff' 'sin(x)' -y '$y$ values' 
+
+# # This should not crash hard
+# $ct -t "Error" '0.0/0.0' 
+
+for f in command-files/errors/*.ct2; do
+    $ct -f $f
+done
 
-$ct -x '$x$ values in % of stuff' 'sin(x)' -y '$y$ values' 
